@@ -14,23 +14,27 @@ provides qw/results_are/;
 sub intercept(&) {
     my ($code) = @_;
 
-    my @results;
+    my(@results, $error, $ok);
 
-    local $@;
-    my $ok = eval {
-        Test::Builder::Stream->intercept(sub {
-            my $stream = shift;
-            $stream->exception_followup;
+    {
+        local $@;
+        local $!;
+        local $_;
+        $ok = eval {
+            Test::Builder::Stream->intercept(sub {
+                my $stream = shift;
+                $stream->exception_followup;
 
-            $stream->listen(INTERCEPTOR => sub {
-                my ($item) = @_;
-                push @results => $item;
+                $stream->listen(INTERCEPTOR => sub {
+                    my ($item) = @_;
+                    push @results => $item;
+                });
+                $code->();
             });
-            $code->();
-        });
-        1;
-    };
-    my $error = $@;
+            1;
+        };
+        $error = $@ || "Error was squashed!";
+    }
 
     die $error unless $ok || (blessed($error) && $error->isa('Test::Builder::Result'));
 
@@ -126,6 +130,7 @@ sub results_are {
         for my $key (keys %$want) {
             my $wval = $want->{$key};
             my $rtype = reftype($wval) || "";
+            $rtype = 'REGEXP' if $rtype eq 'SCALAR' && "$wval" =~ m/^\(\?[-xism]{5}:.*\)$/;
             my $gval = $fields->{$key};
 
             my $field_ok;
